mod enums;

#[allow(clippy::unreadable_literal, clippy::naive_bytecount)]
mod expressions;

mod arrays;
mod builtins;
mod calls;
mod contracts;
mod events;
mod first;
mod format;
mod function_types;
mod functions;
mod imports;
mod inheritance;
mod libraries;
mod loops;
mod mappings;
mod modifier;
mod primitives;
mod storage;
mod strings;
mod structs;
mod value;
mod variables;
